// Copyright 2021 The Gitea Authors. All rights reserved.
// SPDX-License-Identifier: MIT

package v1_19

import (
	"testing"

	"code.gitea.io/gitea/models/migrations/base"
)

func TestMain(m *testing.M) {
	base.MainTest(m)
}
